@@ -232,6 +232,9 @@ def lemonhd_upload_anime(web,file1,record_path,qbinfo):
 
     downloadurl=finddownloadurl(driver=web.driver,elementstr='/html/body/table[2]/tbody/tr[2]/td/table[1]/tbody/tr[10]/td[2]/a[2]')
     
+    if downloadurl=='已存在':
+        return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+web.driver.current_url
+
     recordupload(os.path.join(record_path,web.site.sitename+'_torrent.csv'),file1,String_url,downloadurl)
 
     if not downloadurl =='':
