@@ -33,6 +33,7 @@ def pter_upload(web,file1,record_path,qbinfo):
     except Exception as r:
         logger.warning('填写主标题发生错误，错误信息: %s' %(r))
         return False,fileinfo+'填写主标题发生错误'
+
     try:
         #web.driver.find_elements_by_name('small_descr')[0].click()
         web.driver.find_elements_by_name('small_descr')[0].send_keys(file1.small_descr)
@@ -56,6 +57,7 @@ def pter_upload(web,file1,record_path,qbinfo):
         logger.warning('填写IMDb链接发生错误，错误信息: %s' %(r))
         return False,fileinfo+'填写IMDb链接发生错误'
 
+    logger.info('正在填写简介,请稍等...')
     try:
         #web.driver.find_elements_by_name('descr')[0].click()
         web.driver.find_elements_by_name('descr')[0].send_keys(file1.content)
@@ -171,6 +173,9 @@ def pter_upload(web,file1,record_path,qbinfo):
     String_url =finduploadurl(web.driver)
 
     downloadurl=finddownloadurl(driver=web.driver,elementstr='/html/body/table[2]/tbody/tr[2]/td/table[1]/tbody/tr[9]/td[2]/a')
+    if downloadurl=='已存在':
+        return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+web.driver.current_url
+
     
     recordupload(os.path.join(record_path,web.site.sitename+'_torrent.csv'),file1,String_url,downloadurl)
     if not downloadurl =='':
@@ -178,7 +183,7 @@ def pter_upload(web,file1,record_path,qbinfo):
         if res:
             return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
         else:
-            return True,fileinfo+'添加种子失败,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
+            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
     else:
         return False,fileinfo+'未找到下载链接,当前网址:'+web.driver.current_url
 
